import Block from "./Block";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
/** Represents a divider block element (horizontal line placed between blocks); */
export declare class Divider extends Block {
    /** Create a new divider with given (optional) properties */
    constructor(color?: string, thickness?: string, margin?: string, insetLeft?: string, insetRight?: string);
    /** Initialize a divider (block element) factory with given values */
    static with: (values: Divider.Initializer) => ComponentFactory<Divider>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: Divider.Initializer) => this;
    /** Line style, e.g. dashed, dotted, double, solid (CSS value, observed) */
    lineStyle: string;
    /** Divider color (observed) */
    color: string;
    /** Divider thickness (CSS value, observed) */
    thickness: string;
    /** Vertical whitespace around divider (CSS value, observed) */
    margin: string;
    /** Horizontal inset on left side (CSS value, observed) */
    insetLeft: string;
    /** Horizontal inset on right side (CSS value, observed) */
    insetRight: string;
    /** Default line color (black, 90% transparency) */
    static DEFAULT_COLOR: string;
    /** Default line thickness (1px) */
    static DEFAULT_THICKNESS: string;
    /** Default line style (solid) */
    static DEFAULT_LINE_STYLE: string;
    /** Default margin (1/2 rem) */
    static DEFAULT_MARGIN: string;
}
export declare namespace Divider {
    /** Initializer for .with({ ... }) */
    interface Initializer extends Block.Initializer {
        /** Property initializer */
        lineStyle?: ValueOrAsync<string>;
        /** Property initializer */
        color?: ValueOrAsync<string>;
        /** Property initializer */
        thickness?: ValueOrAsync<string>;
        /** Property initializer */
        margin?: ValueOrAsync<string>;
        /** Property initializer */
        insetLeft?: ValueOrAsync<string>;
        /** Property initializer */
        insetRight?: ValueOrAsync<string>;
    }
}
export default Divider;
