import Async from "typescene-async";
import Block from "./Block";
import Divider from "./Divider";
import Component from "../Component";
import { EventHandlerCtor } from "../DOMEvents";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
import { ActionHandler } from "../DOMEvents";
/** Represents a list of blocks */
export declare class List<BlockT extends Block> extends Block {
    /** Create a list component with given block items, if any */
    constructor(items?: BlockT[] | Async.ObservableArray<BlockT>);
    /** Initialize a list factory with given values */
    static with<BlockT extends Block>(values: List.Initializer<BlockT>): ComponentFactory<List<BlockT>>;
    /** Initialize a list factory with given items */
    static withItems<BlockT extends Block>(items: ComponentFactory.SpecList): ComponentFactory<List<BlockT>>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: List.Initializer<BlockT>) => this;
    /** List content (observed) */
    items: (BlockT | null)[];
    /** Set to an initializer spec for the Divider component to insert a line between each element (observed) */
    divider: Divider.Initializer;
    /** Set to true to enable element selection using click and up/down arrow keys (observed) */
    allowSelection: boolean;
    /** Currently selected item (Block), if any (observed) */
    selectedItem: BlockT | null;
    /** Currently selected item index (base 0) or -1 if no selection (observed/able) */
    selectedIndex: number;
    /** Set to a string value to have getFormValues add an ObservableArray with form values of list items */
    name: string;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
    /** Returns an object containing all current values of input elements (observable) */
    getFormValues(result?: {}): {};
    /** Sets all input values by element name (will not trigger observable) */
    setFormValues(values: any): void;
    /** Signal emitted when the list selection changes */
    readonly SelectionChange: ListSelectionSignal<BlockT>;
    private _clickConnections;
    private _dividers;
}
export declare namespace List {
    /** Initializer for .with({ ... }) */
    interface Initializer<BlockT extends Block> extends Block.Initializer {
        /** Property initializer: property name or list of items */
        items: string | ComponentFactory.SpecList;
        /** Divider initializer spec */
        divider?: Divider.Initializer;
        /** Property initializer */
        allowSelection?: ValueOrAsync<boolean>;
        /** Property initializer */
        selectedItem?: ValueOrAsync<BlockT>;
        /** Property initializer */
        selectedIndex?: ValueOrAsync<number>;
        /** Property initializer */
        name?: string;
        /** Signal initializer: method name or handler */
        SelectionChange?: string | ListSelectionHandler<BlockT>;
    }
}
/** Event data that is emitted when a list's selection changes */
export interface ListSelectionEvent<T extends Block> {
    /** The list component itself */
    list: List<T>;
    /** The new selection index */
    selectedIndex: number;
    /** The newly selected item */
    selectedItem: T | null;
}
/** Signal that is emitted when a list's selection changes */
export interface ListSelectionSignal<T extends Block> extends Async.CustomSignalClass<ListSelectionEvent<T>, Async.Signal<ListSelectionEvent<T>>> {
}
/** [implementation] */
export interface ListSelectionHandler<T extends Block> extends ActionHandler<ListSelectionEvent<T>, ListSelectionSignal<T>> {
}
/** Constructor for a list selection change handler */
export declare var ListSelectionHandler: EventHandlerCtor<ListSelectionEvent<any>, ListSelectionHandler<any>>;
export default List;
