import Component from "../Component";
import Container from "./Container";
import { Row } from "../";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
/** Represents a full app layout container with sub containers for header, footer, left and/or right gutters, and stacked blocks in the main area */
export declare class LayoutContainer extends Container {
    /** Initialize a LayoutContainer factory with given values */
    static with(values: LayoutContainer.Initializer): ComponentFactory<LayoutContainer>;
    /** Initialize a LayoutContainer factory with given content */
    static withContent: (content: ComponentFactory.SpecList2) => ComponentFactory<LayoutContainer>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: LayoutContainer.Initializer) => this;
    /** Default left gutter width (CSS value, initially 18rem) */
    static LEFT_GUTTER_WIDTH: string;
    /** Default right gutter width (CSS value, initially 22rem) */
    static RIGHT_GUTTER_WIDTH: string;
    /** Default header height (CSS value, initially 4rem) */
    static HEADER_HEIGHT: string;
    /** Default footer height (CSS value, initially 2rem) */
    static FOOTER_HEIGHT: string;
    /** Header container, if any (observed) */
    header: Container | null;
    /** Header height (CSS value), must be fixed (observed) */
    headerHeight: string;
    /** Footer container, if any (observed) */
    footer: Container | null;
    /** Footer height (CSS value), must be fixed (observed) */
    footerHeight: string;
    /** Left gutter container, if any (observed) */
    leftGutter: Container | null;
    /** Left gutter width (CSS value), must be fixed (observed) */
    leftGutterWidth: string;
    /** Right gutter container, if any (observed) */
    rightGutter: Container | null;
    /** Right gutter width (CSS value), must be fixed (observed) */
    rightGutterWidth: string;
    /** True to make content within container scrollable (overflow: auto); defaults to true for LayoutContainer (observed) */
    scrollable: boolean;
    /** Use given row (or row initializer) as a fixed-height header */
    setHeaderRow(height: string, row: Row | Row.Initializer | ComponentFactory.SpecEltOrList): void;
    /** Use given row (or row initializer) as a fixed-height footer */
    setFooterRow(height: string, row: Row | Row.Initializer | ComponentFactory.SpecEltOrList): void;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
    private _centerWrapper;
    private _headerWrapper;
    private _footerWrapper;
    private _leftWrapper;
    private _rightWrapper;
}
export declare namespace LayoutContainer {
    /** Initializer for .with({ ... }) */
    interface Initializer extends Container.Initializer {
        /** Property initializer */
        header?: ComponentFactory.SpecEltOrList | null;
        /** Property initializer */
        headerHeight?: ValueOrAsync<string>;
        /** Property initializer */
        footer?: ComponentFactory.SpecEltOrList | null;
        /** Property initializer */
        footerHeight?: ValueOrAsync<string>;
        /** Property initializer */
        leftGutter?: ComponentFactory.SpecEltOrList | null;
        /** Property initializer */
        leftGutterWidth?: ValueOrAsync<string>;
        /** Property initializer */
        rightGutter?: ComponentFactory.SpecEltOrList | null;
        /** Property initializer */
        rightGutterWidth?: ValueOrAsync<string>;
    }
}
export default LayoutContainer;
