import { Block } from "../";
import ControlElement from "./ControlElement";
import Component from "../Component";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
/** Represents a control element that contains a block */
export declare class BlockControl<BlockT extends Block> extends ControlElement {
    /** Create a new block control element containing the given block, if any */
    constructor(block?: BlockT | Block);
    /** Initialize a block control element factory with given values */
    static with<BlockT extends Block>(values: BlockControl.Initializer): ComponentFactory<BlockControl<BlockT>>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: BlockControl.Initializer) => this;
    /** Block element (defaults to plain Row but may be changed or set to null; observed) */
    block: BlockT | null;
    /** Height (CSS value), default auto (observed) */
    height: string;
    /** Returns an array of directly contained UI components (observable) */
    getChildren(): Component[];
}
export declare namespace BlockControl {
    interface Initializer extends ControlElement.Initializer {
        block: ComponentFactory.SpecEltOrList | null;
        height?: ValueOrAsync<string>;
    }
}
export default BlockControl;
