import Style from "../../Style";
import ControlElement from "./ControlElement";
import { ComponentFactory, ValueOrAsync } from "../ComponentFactory";
import TextLabelFactory from "../TextLabelFactory";
/** Represents a minimal text control with icon and badge */
export declare class Label extends ControlElement {
    /** Create a label element */
    constructor(text?: string | TextLabelFactory, icon?: string, remGutter?: number, badge?: string | TextLabelFactory);
    /** Initialize a text control factory with given values */
    static with: (values: Label.Initializer) => ComponentFactory<Label>;
    /** Initialize a text control factory with given text and style */
    static withText(text: ValueOrAsync<string | TextLabelFactory>, style?: ValueOrAsync<Style | Style.StyleSet>): ComponentFactory<Label>;
    /** Initialize with given (observable) values; returns this */
    initializeWith: (values: Label.Initializer) => this;
    /** Text to display (observed) */
    text: string;
    /** Icon to be placed in front of the label text (CSS class(es), e.g. "glyphicon-edit" or "fa-edit fa-2x"; first part is repeated Bootstrap-style automatically, e.g. "fa-edit" becomes "fa fa-edit"; observed); style properties can be appended like "fa-edit color=#ccc fontSize=200%" (or font-size); use quotes to wrap values with spaces, e.g. 'fa-edit border="1px solid #ccc"' */
    icon: string | undefined;
    /** Space reserved for icon (rem units), if > 0 (observed) */
    remGutter: number;
    /** Badge text, if any (observed) */
    badge: string;
    /** Tooltip text (title attribute; observed) */
    tooltipTitle: string;
    /** True if user is allowed to focus this text as an input control (observed) */
    focusable: boolean;
    /** Set to false to expand horizontally within row (observed) */
    shrinkwrap: boolean;
    /** Replace contents of given node with icon, label, and badge, if any */
    static renderInto(node: Node, icon?: string, gt?: number, label?: string | TextLabelFactory, badge?: string | TextLabelFactory, append?: boolean, iconRight?: boolean): Node;
    protected focus(): void;
    protected blur(): void;
}
export declare namespace Label {
    /** Initializer for .with({ ... }) */
    interface Initializer extends ControlElement.Initializer {
        /** Property initializer */
        text: ValueOrAsync<string | TextLabelFactory>;
        /** Property initializer */
        icon?: ValueOrAsync<string>;
        /** Property initializer */
        remGutter?: ValueOrAsync<number>;
        /** Property initializer */
        badge?: ValueOrAsync<string | TextLabelFactory>;
        /** Property initializer */
        focusable?: ValueOrAsync<boolean>;
        /** Property initializer */
        tooltipTitle?: ValueOrAsync<string | TextLabelFactory>;
    }
}
/** Stretched label control: a label that expands horizontally, while not breaking across lines (uses ellipsis if available) */
export declare class WideLabel extends Label {
    constructor(text?: string | TextLabelFactory, icon?: string, remGutter?: number, badge?: string | TextLabelFactory);
    /** Set to true to shrink horizontally (default false; observed) */
    shrinkwrap: boolean;
}
/** Paragraph control: a label that expands horizontally, with text that breaks automatically across lines, and added line spacing */
export declare class Paragraph extends Label {
    /** Line height for paragraph labels (CSS value, default 1.65em) */
    static LINE_HEIGHT: string;
    /** Set to true to shrink horizontally (default false; observed) */
    shrinkwrap: boolean;
    /** Automatically break text across lines (default true, observed) */
    wrapText: boolean;
}
/** H1 label control */
export declare class Heading1 extends Label {
    constructor(text?: string | TextLabelFactory, icon?: string, remGutter?: number, badge?: string | TextLabelFactory);
    protected tagName: string;
}
/** H2 label control */
export declare class Heading2 extends Heading1 {
    protected tagName: string;
}
/** H3 label control */
export declare class Heading3 extends Heading1 {
    protected tagName: string;
}
/** H4 label control */
export declare class Heading4 extends Heading1 {
    protected tagName: string;
}
/** H5 label control */
export declare class Heading5 extends Heading1 {
    protected tagName: string;
}
/** H6 label control */
export declare class Heading6 extends Heading1 {
    protected tagName: string;
}
export default Label;
