import { CustomSignalClass, Signal } from "typescene-async";
import TextLabelFactory from "../TextLabelFactory";
import { DialogContainer } from "../";
import ComponentFactory from "../ComponentFactory";
/** Represents a generic confirmation dialog with Confirm and Cancel options, contains either a single Paragraph component, or a stack initialized with given texts; emits Confirmed signal when confirm button is clicked */
export declare class ConfirmationDialog extends DialogContainer {
    static initializer: ComponentFactory<DialogContainer>;
    /** Create a confirmation dialog with given text */
    constructor(headerText: string | TextLabelFactory, messageText: string | TextLabelFactory, confirmButtonLabel?: string | TextLabelFactory, cancelButtonLabel?: string | TextLabelFactory);
    /** Create a confirmation dialog with given texts stacked vertically */
    constructor(headerText: string | TextLabelFactory, messageTexts: (string | TextLabelFactory)[], confirmButtonLabel?: string | TextLabelFactory, cancelButtonLabel?: string | TextLabelFactory);
    /** Dialog header text, if any */
    headerText?: string | TextLabelFactory;
    /** One or more lines of text to be displayed as main content */
    messageText: string | TextLabelFactory | (string | TextLabelFactory)[];
    /** The confirmation button label (defaults to Confirm) */
    confirmButtonLabel: string | TextLabelFactory;
    /** The cancellation button label (defaults to Cancel) */
    cancelButtonLabel: string | TextLabelFactory;
    /** Signal that is emitted when the confirm button has been clicked */
    readonly Confirmed: CustomSignalClass<void, Signal<void>>;
}
export default ConfirmationDialog;
